Index: runtime/vm/profiler.cc |
diff --git a/runtime/vm/profiler.cc b/runtime/vm/profiler.cc |
index 22febb0dabbe8ba3a1fefe4ecea920912cc93028..05f830292c76c03c54568a4fac18debcebb55717 100644 |
--- a/runtime/vm/profiler.cc |
+++ b/runtime/vm/profiler.cc |
@@ -1104,10 +1104,11 @@ void Profiler::SampleThread(Thread* thread, |
return; |
} |
- if (StubCode::HasBeenInitialized() && StubCode::InJumpToFrameStub(state.pc)) { |
- // The JumpToFrame stub manually adjusts the stack pointer, frame |
- // pointer, and some isolate state. It is not safe to walk the |
- // stack when executing this stub. |
+ if (StubCode::HasBeenInitialized() && |
+ StubCode::InJumpToExceptionHandlerStub(state.pc)) { |
+ // The JumpToExceptionHandler stub manually adjusts the stack pointer, |
+ // frame pointer, and some isolate state before jumping to a catch entry. |
+ // It is not safe to walk the stack when executing this stub. |
AtomicOperations::IncrementInt64By( |
&counters_.bail_out_jump_to_exception_handler, 1); |
return; |